# -*- coding: utf-8 -*-
from setuphelpers import *
import json
import shutil


def update_package():
    # Declaring local variables
    package_updated = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    api_url = "https://api.github.com/repos/belowaverage-org/SuperGrate/releases/latest"
    os_dict = {"windows": "Release.zip", "linux": ".AppImage", "darwin": ".dmg"}
    arch_dict = {"x64": "Release_64", "x86": "Release"}

    # Getting latest version information from official sources
    print("API used is: %s" % api_url)
    json_load = json.loads(wgets(api_url, proxies=proxies))
    for to_download in json_load["assets"]:
        if os_dict[control.target_os] in to_download["name"]:
            download_url = to_download["browser_download_url"]
            version = json_load["tag_name"].split("-")[-1].replace("v", "")
            latest_bin = to_download["name"]
            break

    # Downloading latest binaries
    print("Latest %s version is: %s" % (control.name, version))
    print("Download URL is: %s" % download_url)
    if Version(version) != Version(get_file_properties("SuperGrate.exe")["FileVersion"]) or isfile("SuperGrate.exe"):
        if isfile("SuperGrate.exe"):
            remove_file("SuperGrate.exe")
        print("Downloading: %s" % latest_bin)
        wget(download_url, latest_bin, proxies=proxies)
    else:
        print("Binary is present: %s" % latest_bin)

    # Checking version from file
    version_from_file = get_version_from_binary(latest_bin).split("-")[0]
    # if not version_from_file.startswith(version) and version_from_file != '':
    if Version(version_from_file) != Version(version) and version_from_file != "":
        print("Changing version to the version number of the binary")
        os.rename(latest_bin, latest_bin.replace(version, version_from_file))
        version = version_from_file
    else:
        print("Binary file version corresponds to online version")

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        package_updated = True
    else:
        print("Software version up-to-date (%s)" % Version(version))
    control.set_software_version(version)
    control.save_control_to_wapt()

    unzip(latest_bin)
    remove_file(latest_bin)
    shutil.move(glob.glob(f".\\Release\\{arch_dict[control.architecture]}\\SuperGrate.exe")[0], basedir)
    remove_tree("Release")
    # Deleting outdated binaries
    remove_outdated_binaries(version)

    # Validating update-package-sources
    return package_updated
